@@ -11,7 +11,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(to_ascii to_latin1);
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT ]);
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 
 our %ANSI_TO_ASCII_TRANSLITERATION = (qw(
          !
@@ -114,8 +114,11 @@ our %ANSI_TO_ASCII_TRANSLITERATION = (qw(
     );
 
 # remove all unknown chars
-$ANSI_TO_ASCII_TRANSLITERATION{$_} = '' 
-    for (grep {!defined($ANSI_TO_ASCII_TRANSLITERATION{chr $_})} (128..255));
+$ANSI_TO_ASCII_TRANSLITERATION{$_} = ''
+     for (
+       grep { !defined( $ANSI_TO_ASCII_TRANSLITERATION{$_} ) }
+         map { chr $_ } ( 128 .. 255 )
+     );
 
 sub to_ascii($) {
     my $text = shift;
@@ -932,6 +935,7 @@ sub to_latin1($) {
     s/mzzi/muezzi/g;
     s/psy/poesy/g;
     s/(?<=[Tt]omat)/oe/g;
+    s/(?<=B)(?=gehold)/oe/g;
     return $_;
 }
 
